package org.apache.james.mime4j.field.address;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.Serializable;
import java.io.StringReader;
import java.util.AbstractList;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.apache.james.mime4j.field.address.Address;
import org.apache.james.mime4j.field.address.Builder;
import org.apache.james.mime4j.field.address.Mailbox;
import org.apache.james.mime4j.field.address.MailboxList;
import org.apache.james.mime4j.field.address.parser.AddressListParser;
import org.apache.james.mime4j.field.address.parser.ParseException;

public class AddressList extends AbstractList implements Serializable {

   private static final long serialVersionUID = 1L;
   private final List addresses;


   public AddressList(List addresses, boolean dontCopy) {
      if(addresses != null) {
         this.addresses = (List)(dontCopy?addresses:new ArrayList(addresses));
      } else {
         this.addresses = Collections.emptyList();
      }

   }

   public int size() {
      return this.addresses.size();
   }

   public Address get(int index) {
      return (Address)this.addresses.get(index);
   }

   public MailboxList flatten() {
      boolean groupDetected = false;
      Iterator results = this.addresses.iterator();

      while(results.hasNext()) {
         Address i$ = (Address)results.next();
         if(!(i$ instanceof Mailbox)) {
            groupDetected = true;
            break;
         }
      }

      if(!groupDetected) {
         List results2 = this.addresses;
         return new MailboxList(results2, true);
      } else {
         ArrayList results1 = new ArrayList();
         Iterator i$1 = this.addresses.iterator();

         while(i$1.hasNext()) {
            Address addr = (Address)i$1.next();
            addr.addMailboxesTo(results1);
         }

         return new MailboxList(results1, false);
      }
   }

   public void print() {
      Iterator i$ = this.addresses.iterator();

      while(i$.hasNext()) {
         Address addr = (Address)i$.next();
         System.out.println(addr.toString());
      }

   }

   public static AddressList parse(String rawAddressList) throws ParseException {
      AddressListParser parser = new AddressListParser(new StringReader(rawAddressList));
      return Builder.getInstance().buildAddressList(parser.parseAddressList());
   }

   public static void main(String[] args) throws Exception {
      BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));

      while(true) {
         try {
            System.out.print("> ");
            String e = reader.readLine();
            if(e.length() == 0 || e.toLowerCase().equals("exit") || e.toLowerCase().equals("quit")) {
               System.out.println("Goodbye.");
               return;
            }

            AddressList list = parse(e);
            list.print();
         } catch (Exception var4) {
            var4.printStackTrace();
            Thread.sleep(300L);
         }
      }
   }
}
